==> nextcloud-18.0.6.tgz: nextcloud/apps/twofactor_backupcodes/l10n/uk.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Ви створили резервні коди для двофакторної авторизації у вашому обліковому записі",
    "Second-factor backup codes" : "Резервні коди другого фактору",
    "Generate backup codes" : "Створити резервні коди",
    "Backup code" : "Резервні коди",
    "Use backup code" : "Використати резервний код",
    "Two factor backup codes" : "Резервні коди двофакторної авторизації",
    "A two-factor auth backup codes provider" : "Провайдер резервних кодів двофакторної авторизації",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Створено резервні коди. Вже використано {used} із {total} кодів.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Це ваші резервні коди. Будь ласка, збережіть їх та у разі потреби роздрукуйте, оскільки подалі вони ніде не будуть показуватися.",
    "Save backup codes" : "Зберегти резервні коди",
    "Print backup codes" : "Друк резервних кодів",
    "Regenerate backup codes" : "Перестворити резервні коди",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Після повторного створення резервних кодів попередні автоматично стануть недійсними",
    "An error occurred while generating your backup codes" : "Помилка під час створення резервних кодів",
    "{name} backup codes" : "Резервні коди {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Скористайтеся одним з резервних кодів, які ви зберегли під час встановлення двофакторної авторизації.",
    "Submit" : "Гаразд",
    "function" : "функція"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-18.0.7.tgz: nextcloud/apps/twofactor_backupcodes/l10n/uk.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Ви створили резервні коди для двофакторної автентифікації у вашому обліковому записі",
    "Second-factor backup codes" : "Резервні коди другого фактору",
    "Generate backup codes" : "Створити резервні коди",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Ви увімкнули двофакторну автентифікацію, але ще не створили резервні коди. Вони потрібні для відновлення доступу до вашого облікового запису, якщо ви втратите другий фактор.",
    "Backup code" : "Резервні коди",
    "Use backup code" : "Використати резервний код",
    "Two factor backup codes" : "Резервні коди двофакторної автентифікації",
    "A two-factor auth backup codes provider" : "Провайдер резервних кодів двофакторної автентифікації",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Створено резервні коди. Вже використано {used} із {total} кодів.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Це ваші резервні коди. Будь ласка, збережіть їх та у разі потреби роздрукуйте, оскільки подалі вони ніде не будуть показуватися.",
    "Save backup codes" : "Зберегти резервні коди",
    "Print backup codes" : "Друк резервних кодів",
    "Regenerate backup codes" : "Перестворити резервні коди",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Після повторного створення резервних кодів попередні автоматично стануть недійсними",
    "An error occurred while generating your backup codes" : "Помилка під час створення резервних кодів",
    "{name} backup codes" : "Резервні коди {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Скористайтеся одним з резервних кодів, які ви зберегли під час встановлення двофакторної автентифікації.",
    "Submit" : "Гаразд",
    "function" : "функція"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
